web2ldap - Web-based LDAPv3 client
==================================

See HTML documentation in htdocs/ or visit
[https://www.web2ldap.de](https://www.web2ldap.de)

What is web2ldap?
-----------------

  * A generic LDAPv3 client which does not make any assumptions
    about the tree structure or LDAP schema.
  * Kind of a swiss-army knife for accessing/manipulating
    LDAP servers without having to configure anything.
  * A secure LDAP client with clean login behaviour.
  * A schema browser which displays references/dependencies
    within an LDAPv3 schema.
  * A customizable platform for prototyping LDAP administration use-cases.
  * For me it is a platform for implementing cutting edge LDAP features.
  * Continuously maintained software since September 1998!

Project status
--------------

This software is still actively developed.
Check the [change log](https://www.web2ldap.de/changes.html) and the
[roadmap](https://www.web2ldap.de/roadmap.html).
